@@ -8,13 +8,7 @@
     SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
-#include <QtGlobal>
-
-#ifdef Q_OS_WIN
-// Prevent windows system header files from defining min/max as macros.
-#define NOMINMAX 1
-#include <winsock2.h>
-#endif
+#include <QtSystemDetection>
 
 #include "transfersend.h"
 #include "dcccommon.h"
@@ -38,6 +32,12 @@
 #include <KIO/StatJob>
 #include <KIO/CopyJob>
 
+#ifdef Q_OS_WIN
+// Prevent windows system header files from defining min/max as macros.
+#define NOMINMAX 1
+#include <winsock2.h>
+#endif
+
 using namespace Konversation::UPnP;
 
 namespace Konversation
